@@ -1,5 +1,7 @@
 from __future__ import annotations
 from abc import abstractmethod
+from fastapi_datatables.filtration import FiltrationData
+from fastapi import Depends
 
 from pydantic import BaseModel
 from typing import Callable, Iterable, Iterator, get_type_hints, Union, Any, Optional
@@ -41,9 +43,13 @@ class Filterable:
         return table_name @ res
 
     @classmethod
-    def filter(cls) -> Callable:
+    def filter(cls) -> Callable[..., FiltrationData]:
         return get_filtration(cls.fields())
 
     @classmethod
     def __ignore_fields__(cls) -> set[str]:
         return set()
+
+
+def Filter(f: Filterable) -> FiltrationData:
+    return Depends(f.filter())
\ No newline at end of file
